Struct ArkoorBuilder

pub struct ArkoorBuilder<S: BuilderState> { /* private fields */ }

Implementations

Source

impl<S: BuilderState> ArkoorBuilder<S>

pub fn input(&self) -> &Vtxo<Full>

Access the input VTXO

pub fn normal_outputs(&self) -> &[ArkoorDestination]

Access the regular (non-isolated) outputs of the builder

pub fn isolated_outputs(&self) -> &[ArkoorDestination]

Access the isolated outputs of the builder

pub fn all_outputs(&self) -> impl Iterator<Item = &ArkoorDestination> + Clone

Access all outputs of the builder

pub fn build_unsigned_vtxos<'a>( &'a self, ) -> impl Iterator<Item = Vtxo<Full>> + 'a

pub fn build_unsigned_internal_vtxos<'a>( &'a self, ) -> impl Iterator<Item = ServerVtxo<Full>> + 'a

Builds the unsigned internal VTXOs

Returns the checkpoint outputs (if checkpoinst are used) and the dust isolation output (if dust isolation is used).

pub fn spend_info(&self) -> Vec<(VtxoId, Txid)>

The returned VtxoId is spent out-of-round by Txid

pub fn virtual_transactions(&self) -> Vec<Txid>

Returns the txids of all virtual transactions in this arkoor:

  • checkpoint tx (if checkpoints enabled)
  • arkoor txs (one per normal output, exits from checkpoint)
  • isolation fanout tx (if dust isolation active)
Source

impl ArkoorBuilder<Initial>

pub fn new_with_checkpoint( input: Vtxo<Full>, outputs: Vec<ArkoorDestination>, isolated_outputs: Vec<ArkoorDestination>, ) -> Result<Self, ArkoorConstructionError>

Create builder with checkpoint transaction

pub fn new_without_checkpoint( input: Vtxo<Full>, outputs: Vec<ArkoorDestination>, isolated_outputs: Vec<ArkoorDestination>, ) -> Result<Self, ArkoorConstructionError>

Create builder without checkpoint transaction

pub fn new_with_checkpoint_isolate_dust( input: Vtxo<Full>, outputs: Vec<ArkoorDestination>, ) -> Result<Self, ArkoorConstructionError>

Create builder with checkpoint and automatic dust isolation

This constructor takes a single list of outputs and automatically determines the best strategy for handling dust.

pub fn generate_user_nonces( self, user_keypair: Keypair, ) -> ArkoorBuilder<UserGeneratedNonces>

Generates the user nonces and moves the builder to the state::UserGeneratedNonces state This is the path that is used by the user

Source

impl<'a> ArkoorBuilder<ServerCanCosign>

Source

impl ArkoorBuilder<ServerSigned>

Source

impl ArkoorBuilder<UserGeneratedNonces>

Source

impl<'a> ArkoorBuilder<UserSigned>